@@ -1,26 +1,11 @@
-/* ****************************************************************************
+/*
   This file is part of Lokalize
 
-  Copyright (C) 2007-2011 by Nick Shaforostoff <shafff@ukr.net>
-                2018-2019 by Simon Depiets <sdepiets@gmail.com>
+  SPDX-FileCopyrightText: 2007-2011 Nick Shaforostoff <shafff@ukr.net>
+  SPDX-FileCopyrightText: 2018-2019 Simon Depiets <sdepiets@gmail.com>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-**************************************************************************** */
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "prefs.h"
 
@@ -49,9 +34,6 @@
 #include <KMessageBox>
 #include <KEditListWidget>
 #include <KConfigDialog>
-#include <kross/core/manager.h>
-#include <kross/core/actioncollection.h>
-#include <kross/ui/model.h>
 
 #include <QIcon>
 #include <QBoxLayout>
@@ -83,7 +65,6 @@ SettingsController* SettingsController::instance()
 SettingsController::SettingsController()
     : QObject(Project::instance())
     , dirty(false)
-    , m_projectActionsView(nullptr)
     , m_mainWindowPtr(nullptr)
 {}
 
@@ -187,29 +168,6 @@ void SettingsController::showSettingsDialog()
 
 }
 
-
-
-
-ScriptsView::ScriptsView(QWidget* parent): Kross::ActionCollectionView(parent)
-{
-    setAcceptDrops(true);
-}
-
-void ScriptsView::dragEnterEvent(QDragEnterEvent* event)
-{
-    if (!event->mimeData()->urls().isEmpty() && event->mimeData()->urls().first().path().endsWith(QLatin1String(".rc")))
-        event->accept();
-}
-
-void ScriptsView::dropEvent(QDropEvent* event)
-{
-    Kross::ActionCollectionModel* scriptsModel = static_cast<Kross::ActionCollectionModel*>(model());
-    const auto urls = event->mimeData()->urls();
-    for (const QUrl& url : urls)
-        if (url.path().endsWith(QLatin1String(".rc")))
-            scriptsModel->rootCollection()->readXmlFile(url.path());
-}
-
 bool SettingsController::ensureProjectIsLoaded()
 {
     if (Project::instance()->isLoaded())
@@ -253,12 +211,6 @@ bool SettingsController::projectCreate()
     if (path.isEmpty())
         return false;
 
-    if (m_projectActionsView && m_projectActionsView->model()) {
-        //ActionCollectionModel is known to be have bad for the usecase of reinitializing krossplugin
-        m_projectActionsView->model()->deleteLater();
-        m_projectActionsView->setModel(nullptr);
-    }
-
     //TODO ask-n-save
     QDir projectFolder = QFileInfo(path).absoluteDir();
     QString projectId = projectFolder.dirName();
@@ -279,12 +231,6 @@ void SettingsController::projectConfigure()
         return;
     }
 
-    if (KConfigDialog::showDialog("project_settings")) {
-        if (!m_projectActionsView->model())
-            m_projectActionsView->setModel(new Kross::ActionCollectionModel(m_projectActionsView, Kross::Manager::self().actionCollection()->collection(Project::instance()->kind())));
-        return;
-    }
-
     KConfigDialog *dialog = new KConfigDialog(m_mainWindowPtr, "project_settings", Project::instance());
     dialog->setFaceType(KPageDialog::List);
 
@@ -347,20 +293,6 @@ void SettingsController::projectConfigure()
     layout->setSpacing(6);
     layout->setContentsMargins(11, 11, 11, 11);
 
-
-    //m_projectActionsEditor=new Kross::ActionCollectionEditor(Kross::Manager::self().actionCollection()->collection(Project::instance()->projectID()),w);
-    m_projectActionsView = new ScriptsView(w);
-    layout->addWidget(m_projectActionsView);
-    m_projectActionsView->setModel(new Kross::ActionCollectionModel(w, Kross::Manager::self().actionCollection()->collection(Project::instance()->kind())));
-
-    QHBoxLayout* btns = new QHBoxLayout();
-    layout->addLayout(btns);
-    btns->addWidget(m_projectActionsView->createButton(w, "edit"));
-
-
-    dialog->addPage(w, i18nc("@title:tab", "Scripts"), "preferences-system-windows-actions");
-
-
     w = new QWidget(dialog);
     Ui_prefs_project_local ui_prefs_project_local;
     ui_prefs_project_local.setupUi(w);
