@@ -549,7 +549,7 @@ bool TMView::event(QEvent *event)
             return true;
         }
     }
-    return QWidget::event(event);
+    return QDockWidget::event(event);
 }
 
 void TMView::removeEntry(const TMEntry& e)
